@@ -59,7 +59,7 @@ my $my = {
 my $opt = {
     -help     => 0,
     -version  => 0,
-    -config   => 'flow2rrd.cfg',
+    -config   => '@SYSCONFDIR@/flow2rrd.cfg',
     -store    => 0,
     -graph    => 0,
     -cgi      => (($ENV{'GATEWAY_INTERFACE'} || "") eq 'CGI/1.1' ? 1 : 0)
